;; Generated package description from posframe.el  -*- no-byte-compile: t -*-
(define-package "posframe" "1.5.1" "Pop a posframe (just a frame) at point" '((emacs "26.1")) :commit "4fc893c3c9ea3f6b5099ac1b369abb3c6da40b1e" :authors '(("Feng Shu" . "tumashu@163.com")) :maintainer '("Feng Shu" . "tumashu@163.com") :keywords '("convenience" "tooltip") :url "https://github.com/tumashu/posframe")
